==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/config_wizard/translations/config_wizard_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu necesita ser reiniciado antes que los cambios a la configuración de lenguaje tengan efecto.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Red de IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Quiero configurar una cuenta existente para Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Quiero crear una nueva cuenta para Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>No quiero crear mi cuenta para Kadu ahora</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor elija la red de la cuenta que desea configurar.&lt;/p&gt;&lt;p&gt;También puede crear una nueva cuenta en el asistente si usted todavía no tiene una&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Asistente de Configuración Completó&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Ir a Configuración de Cuentas después de cerrar esta ventana</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirme los ajustes del asistente para empezara utilizar Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Iniciar el Asistente de Configuración</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Bienvenidos al cliente de Mensajeria Instantánea Kadu&lt;/h3&gt;&lt;p&gt;Este asistente le ayudará a configurar los ajustes básicos de Kadu.&lt;/p&gt;&lt;p&gt;Por favor elija un idioma preferido y un apodo&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración del perfil&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apodo</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor introduzca los datos de su cuenta.&lt;/p&gt;&lt;p&gt;Regrese si quiere seleccionar una diferente opción de Configuración de Cuenta.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Asistente de Kadu</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/config_wizard/translations/config_wizard_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu necesita ser reiniciado antes que los cambios a la configuración de lenguaje tengan efecto.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardActions</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Iniciar el Asistente de Configuración</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Red de IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Quiero configurar una cuenta existente para Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Quiero crear una nueva cuenta para Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>No quiero crear mi cuenta para Kadu ahora</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor elija la red de la cuenta que desea configurar.&lt;/p&gt;&lt;p&gt;También puede crear una nueva cuenta en el asistente si usted todavía no tiene una&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Asistente de Configuración Completó&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Ir a Configuración de Cuentas después de cerrar esta ventana</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirme los ajustes del asistente para empezara utilizar Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Bienvenidos al cliente de Mensajeria Instantánea Kadu&lt;/h3&gt;&lt;p&gt;Este asistente le ayudará a configurar los ajustes básicos de Kadu.&lt;/p&gt;&lt;p&gt;Por favor elija un idioma preferido y un apodo&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración del perfil&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apodo</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor introduzca los datos de su cuenta.&lt;/p&gt;&lt;p&gt;Regrese si quiere seleccionar una diferente opción de Configuración de Cuenta.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Asistente de Kadu</translation>
    </message>
</context>
</TS>
